require(FrF2)

## found in Hamada and Wu 2000 p.484, but with 3 mistakes in response values
## data correction: standard order run 4 must be 0.4, run 9 0.8, run 14 0.5
##                  according to original source Montgomery 1990 Quality Engineering

## Montgomery, D.C. 1990 Using fractional factorial designs for robust process development. 
## Quality Engineering 3, 193-205.

## at the 5% level, all methods except for the new one agree that B,A,AB,AD and c are active only
## the new one adds Aa and AC, with pe3 being higher, however, which gives warning of this, as well as the plot does

## at the 10% level, the linear model remains unchanged; original Lenth adds Aa and AC, 
## the Lenth-based variability methods add Aa only, and the NEW method adds D to its already large model. 

y <- c(0.6, 1, 3.2, 6, 0.4, 1.5, 2.6, 6, 0.8, 1.2, 3.4, 6, 1.6, 0.5, 3.7, 5.2, 2.5, 2.9, 2.4, 2.7)
plan <- FrF2(16,7,randomize=F,ncenter=4,gen=c("ABC","BCD","ACD"),factor.names=c("A","B","C","D","a","b","c"))
plan.resp <- add.response(plan, y)
summary(linmod.ce <- lm(plan.resp,use.center=TRUE,degree=3))
coefNEW <- halfnormal(lm(y~(A+B+C+D+a+b+c)^2,plan.resp[1:16,]),external.pe=c(2.5,2.9,2.4,2.7),external.center=TRUE,alpha=0.1)$coef
## plots
##Figure 1: without center points
par(mfrow=c(1,1))
halfnormal(lm(y~(A+B+C+D+a+b+c)^2,plan.resp[1:16,]), 
   main="Half-normal effects plot for Montgomery 1990 data without center points")  

##Figure 2: with center points
par(mfrow=c(1,3))
halfnormal(coefNEW[1:16],labs=names(coefNEW[1:16]),pch=c(rep(1,14),16,16), 
   main="(a) with nonlinearity check")  

## two different codings, both with lof points as ABD and nonlinearity
aus <- halfnormal(lm(y~(A+B+C+D+a+b+c)^2,plan.resp[1:16,]),external.pe=c(2.5,2.9,2.4,2.7),
  external.center=TRUE,
#halfnormal(coefNEW,labs=names(coefNEW),pch=c(rep(1,14),16,16, 8,8,8), 
   main="(b) with pure error, 1st coding")  

linmod <- lm(y~.^3,plan.resp)
summary(linmod)
## the pch option manually shows ABD as filled dot
coefNEWc <- halfnormal(linmod, main="(c) with pure error, 2nd coding",scl=16,pch=c(rep(1,14),16,16,8,8,8))$coef

## another coding in which the lof points are also changed
## because no explicit precautions are taken against that
## plot not in the paper
linmod2 <- lm(y~.^2,plan.resp)
summary(linmod2)
coefNEWc2 <- halfnormal(linmod2, main="(d) with pure error, 3rd coding",scl=16)$coef



## ignoring the center point completely
linmod <- lm(plan.resp,degree=3)
halfnormal(linmod)

## ignoring the center points completely
b <- abs(coefNEW[1:15])
orig <- ME.Lenth(b)
lapply(orig$ME[c("0.1","0.05","0.01")], function(obj) b[abs(b)>obj])

## incorporating the nonlinear contrast, ignoring pure error
(coef16 <- coefNEW[1:16]) ## with latest version of halfnormal.lm, nonlinear before pe
b <- abs(coef16)
origwithNonlin <- ME.Lenth(b)
lapply(origwithNonlin$ME[c("0.1","0.05","0.01")], function(obj) b[abs(b)>obj])

## including pure error
## lof in conventional style, pe also
NEW_ExMo <- ME.Lenth(coefNEW)
lapply(NEW_ExMo$ME[c("0.1","0.05","0.01")], function(obj) b[abs(b)>obj])

## lof in conventional style, pe different automatic
NEW_ExMoC <- ME.Lenth(coefNEWc)
lapply(NEW_ExMoC$ME[c("0.1","0.05","0.01")], function(obj) b[abs(b)>obj])

## lof different, pe different automatic (not plotted)
NEW_ExMoC2 <- ME.Lenth(coefNEWc2)
lapply(NEW_ExMoC2$ME[c("0.1","0.05","0.01")], function(obj) b[abs(b)>obj])

## LW with nonlin
sterr <- sqrt(vcov(linmod.ce)[2,2])
LW98_ExMo <- CME.LW98(b,sterr,3)
lapply(LW98_ExMo$CME[c("0.1","0.05","0.01")], function(obj) b[abs(b)>obj])

## Edwards Mee with multiplier 1
EM1_ExMo <- CME.EM08(b,sterr,3,weight0=1)
lapply(EM1_ExMo$CME[c("0.1","0.05","0.01")], function(obj) b[abs(b)>obj])

## Edwards Mee with multiplier 5
EM5_ExMo <- CME.EM08(b,sterr,3,weight0=5)
lapply(EM5_ExMo$CME[c("0.1","0.05","0.01")], function(obj) b[abs(b)>obj])
